==> zio-aws-amplifybackend_2.12-5.17.113.1-sources.jar: zio/aws/amplifybackend/model/package.scala <==
package zio.aws.amplifybackend
import zio.prelude.Subtype
import zio.aws.amplifybackend.model.primitives.__string
import zio.aws.amplifybackend.model.primitives.__string.Type
package object model {
  import scala.jdk.CollectionConverters._
  object primitives {
    object __boolean extends Subtype[Boolean]
    type __boolean = zio.aws.amplifybackend.model.primitives.__boolean.Type
    object __double extends Subtype[Double]
    type __double = zio.aws.amplifybackend.model.primitives.__double.Type
    object __integerMin1Max25 extends Subtype[Int]
    type __integerMin1Max25 =
      zio.aws.amplifybackend.model.primitives.__integerMin1Max25.Type
    object __string extends Subtype[String]
    type __string = zio.aws.amplifybackend.model.primitives.__string.Type
  }
  type ListOfAdditionalConstraintsElement =
    List[zio.aws.amplifybackend.model.AdditionalConstraintsElement]
  type ListOfAuthenticatedElement =
    List[zio.aws.amplifybackend.model.AuthenticatedElement]
  type ListOfBackendAPIAuthType =
    List[zio.aws.amplifybackend.model.BackendAPIAuthType]
  type ListOfBackendJobRespObj =
    List[zio.aws.amplifybackend.model.BackendJobRespObj]
  type ListOfMfaTypesElement =
    List[zio.aws.amplifybackend.model.MfaTypesElement]
  type ListOfOAuthScopesElement =
    List[zio.aws.amplifybackend.model.OAuthScopesElement]
  type ListOfRequiredSignUpAttributesElement =
    List[zio.aws.amplifybackend.model.RequiredSignUpAttributesElement]
  type ListOfS3BucketInfo = List[zio.aws.amplifybackend.model.S3BucketInfo]
  type ListOfUnAuthenticatedElement =
    List[zio.aws.amplifybackend.model.UnAuthenticatedElement]
  type ListOf__string = List[__string]
}

==> zio-aws-amplifybackend_3-5.17.102.8-sources.jar: zio/aws/amplifybackend/model/package.scala <==
package zio.aws.amplifybackend
import zio.prelude.Subtype
import zio.aws.amplifybackend.model.primitives.__string
import zio.aws.amplifybackend.model.primitives.__string.Type
package object model {
  import scala.jdk.CollectionConverters.*
  object primitives {
    object __boolean extends Subtype[Boolean]
    type __boolean = zio.aws.amplifybackend.model.primitives.__boolean.Type
    object __double extends Subtype[Double]
    type __double = zio.aws.amplifybackend.model.primitives.__double.Type
    object __integerMin1Max25 extends Subtype[Int]
    type __integerMin1Max25 =
      zio.aws.amplifybackend.model.primitives.__integerMin1Max25.Type
    object __string extends Subtype[String]
    type __string = zio.aws.amplifybackend.model.primitives.__string.Type
  }
  type ListOfAdditionalConstraintsElement =
    List[zio.aws.amplifybackend.model.AdditionalConstraintsElement]
  type ListOfAuthenticatedElement =
    List[zio.aws.amplifybackend.model.AuthenticatedElement]
  type ListOfBackendAPIAuthType =
    List[zio.aws.amplifybackend.model.BackendAPIAuthType]
  type ListOfBackendJobRespObj =
    List[zio.aws.amplifybackend.model.BackendJobRespObj]
  type ListOfMfaTypesElement =
    List[zio.aws.amplifybackend.model.MfaTypesElement]
  type ListOfOAuthScopesElement =
    List[zio.aws.amplifybackend.model.OAuthScopesElement]
  type ListOfRequiredSignUpAttributesElement =
    List[zio.aws.amplifybackend.model.RequiredSignUpAttributesElement]
  type ListOfS3BucketInfo = List[zio.aws.amplifybackend.model.S3BucketInfo]
  type ListOfUnAuthenticatedElement =
    List[zio.aws.amplifybackend.model.UnAuthenticatedElement]
  type ListOf__string = List[__string]
}
